<?php # $Id: serendipity_lang_da.inc.php 1815 2007-08-06 10:18:26Z garvinhicking $
# Copyright (c) 2003-2005, Jannis Hermanns (on behalf the Serendipity Developer Team)
# All rights reserved.  See LICENSE file for licensing details
# Translation (c) by Tom Sommer, <ts@dreamcoder.dk>
# Thanks to: Jeppe Lund, <nocture@nocture.dk>
#            Robert Piil, <robert@piil.org>
/* vim: set sts=4 ts=4 expandtab : */

@define('LANG_CHARSET', 'UTF-8');
@define('SQL_CHARSET', 'utf8');
@define('DATE_LOCALES', 'da_DK.UTF8, da_DK.UTF-8, danish, da, da_DK');
@define('DATE_FORMAT_ENTRY', '%A d. %e. %B %Y');
@define('DATE_FORMAT_SHORT', '%d.%m.%Y %H:%M');
@define('WYSIWYG_LANG', 'da-utf');
@define('LANG_DIRECTION', 'ltr');

@define('SERENDIPITY_ADMIN_SUITE', 'Serendipity Administrationssuite');
@define('HAVE_TO_BE_LOGGED_ON', 'Du skal være logget ind for at kunne se denne side');
@define('WRONG_USERNAME_OR_PASSWORD', 'Du har indtastet et forkert brugernavn eller adgangskode');
@define('APPEARANCE', 'Udseende');
@define('MANAGE_STYLES', 'Administrer skabeloner');
@define('CONFIGURE_PLUGINS', 'Konfigurerer plugins');
@define('CONFIGURATION', 'Konfiguration');
@define('BACK_TO_BLOG', 'Tilbage til weblog');
@define('LOGIN', 'Login');
@define('LOGOUT', 'Log ud');
@define('LOGGEDOUT', 'Logget ud.');
@define('CREATE', 'Opret');
@define('SAVE', 'Gem');
@define('NAME', 'Navn');
@define('CREATE_NEW_CAT', 'Opret ny kategori');
@define('I_WANT_THUMB', 'Jeg vil bruge minibilledet i min artikel.');
@define('I_WANT_BIG_IMAGE', 'Jeg vil bruge det originale billede i min artikel.');
@define('I_WANT_NO_LINK', 'Vis billedet uden link');
@define('I_WANT_IT_TO_LINK', 'Vis billedet med link');
@define('BACK', 'Tilbage');
@define('FORWARD', 'Fremad');
@define('ANONYMOUS', 'Annonym');
@define('NEW_TRACKBACK_TO', 'Ny trackback lavet til');
@define('NEW_COMMENT_TO', 'Ny kommentar lavet til');
@define('RECENT', 'Nyere...');
@define('OLDER', 'Ældre...');
@define('DONE', 'Færdig');
@define('WELCOME_BACK', 'Velkommen tilbage,');
@define('TITLE', 'Titel');
@define('DESCRIPTION', 'Beskrivelse');
@define('PLACEMENT', 'Placering');
@define('DELETE', 'Slet');
@define('UP', 'OP');
@define('DOWN', 'NED');
@define('ENTRIES', 'artikler');
@define('NEW_ENTRY', 'Ny artikel');
@define('EDIT_ENTRIES', 'Rediger artikler');
@define('CATEGORIES', 'Kategorier');
@define('WARNING_THIS_BLAHBLAH', "ADVARSEL:\\nDette kan tage lang tid hvis der er mange billeder uden minibilleder.");
@define('CREATE_THUMBS', 'Genopbyg minibilleder');
@define('MANAGE_IMAGES', 'Administrer billeder');
@define('NAME', 'Navn');
@define('EMAIL', 'Email');
@define('HOMEPAGE', 'Hjemmeside');
@define('COMMENT', 'Kommentar');
@define('REMEMBER_INFO', 'Husk oplysninger?');
@define('SUBMIT_COMMENT', 'Tilføj kommentar');
@define('NO_ENTRIES_TO_PRINT', 'Der er ingen artikler at vise');
@define('COMMENTS', 'Kommentarer');
@define('ADD_COMMENT', 'Tilføj kommentar');
@define('NO_COMMENTS', 'Ingen kommentarer');
@define('POSTED_BY', 'Skrevet af');
@define('ON', 'aktiv');
@define('A_NEW_COMMENT_BLAHBLAH', 'En ny kommentar er blevet oprettet på din blog "%s", til artiklen ved navn "%s".');
@define('A_NEW_TRACKBACK_BLAHBLAH', 'Et nyt trackback er blevet lavet til din artikel ved navn "%s".');
@define('NO_CATEGORY', 'Ingen kategori');
@define('ENTRY_BODY', 'Artikel indhold');
@define('EXTENDED_BODY', 'Udvidet indhold');
@define('CATEGORY', 'Kategori');
@define('EDIT', 'Rediger');
@define('NO_ENTRIES_BLAHBLAH', 'Ingen artikler blev fundet som indeholdt %s' . "\n");
@define('YOUR_SEARCH_RETURNED_BLAHBLAH', 'Din søgning på %s returnerede %s resultater:');
@define('IMAGE', 'Billede');
@define('ERROR_FILE_NOT_EXISTS', 'Fejl: Det gamle filnavn findes ikke!');
@define('ERROR_FILE_EXISTS', 'Fejl: Det nye filnavn eksisterer allerede, vælg et andet!');
@define('ERROR_SOMETHING', 'Fejl: Der gik noget galt');
@define('ADDING_IMAGE', 'Tilføjet billede...');
@define('THUMB_CREATED_DONE', 'Minibillede er oprettet.<br>Done.');
@define('ERROR_FILE_EXISTS_ALREADY', 'Fejl: Filen findes allerede på din maskine!');
@define('GO', 'Begynd!');
@define('NEWSIZE', 'Ny størrelse: ');
@define('RESIZE_BLAHBLAH', '<b>Ændre størrelse på %s</b><p>');
@define('ORIGINAL_SIZE', 'Original størrelse: <i>%sx%s</i> pixel');
@define('HERE_YOU_CAN_ENTER_BLAHBLAH', '<p>Her kan du justere billedets størrelse. Hvis du vil bevare proportionerne, skal du bare indtaste én af værdirene og trykke på TAB-tasten, den anden værdi beregnes så automatisk:');
@define('QUICKJUMP_CALENDAR', 'Hurtigkalender');
@define('QUICKSEARCH', 'Søgning');
@define('SEARCH_FOR_ENTRY', 'Søg efter en artikel');
@define('ARCHIVES', 'Arkiver');
@define('BROWSE_ARCHIVES', 'Gennemse arkiver efter måneder');
@define('TOP_REFERRER', 'Referencer');
@define('SHOWS_TOP_SITES', 'Viser de sites som oftest linker til din blog');
@define('TOP_EXITS', 'Udgangssider');
@define('SHOWS_TOP_EXIT', 'Viser de udgangssider der er klikket flest gange på');
@define('SYNDICATION', 'Syndikering');
@define('SHOWS_RSS_BLAHBLAH', 'Viser RSS syndikeringslinks');
@define('ADVERTISES_BLAHBLAH', 'Reklamer for din blogs oprindelse');
@define('HTML_NUGGET', 'HTML Nugget');
@define('HOLDS_A_BLAHBLAH', 'Indeholder et stykke HTML i din sidebar');
@define('TITLE_FOR_NUGGET', 'Titel på din nugget');
@define('THE_NUGGET', 'HTML-indholdet af din nugget');
@define('SYNDICATE_THIS_BLOG', 'Syndiker denne blog');
@define('YOU_CHOSE', 'Du valgte %s');
@define('IMAGE_SIZE', 'Billedestørrelse');
@define('IMAGE_AS_A_LINK', 'Billedeindsættelse');
@define('POWERED_BY', 'Drives af');
@define('TRACKBACKS', 'Trackbacks');
@define('TRACKBACK', 'Trackback');
@define('NO_TRACKBACKS', 'Ingen Trackbacks');
@define('TOPICS_OF', 'Emner af');
@define('VIEW_FULL', 'Vis i fuld');
@define('VIEW_TOPICS', 'Vis emner');
@define('AT', 'kl');
@define('SET_AS_TEMPLATE', 'Sæt som skabelon');
@define('IN', 'i');
@define('EXCERPT', 'Uddrag');
@define('TRACKED', 'Tracked');
@define('LINK_TO_ENTRY', 'Link til artikel');
@define('LINK_TO_REMOTE_ENTRY', 'Link til ekstern artikel');
@define('IP_ADDRESS', 'IP-adresse');
@define('USER', 'Bruger');
@define('THUMBNAIL_USING_OWN', 'Bruger %s som dets eget minibillede, fordi det allerede er så lille.');
@define('THUMBNAIL_FAILED_COPY', 'Ville gerne have brugt %s som dets egen minibillede, men kunne ikke kopiere!');
@define('AUTHOR', 'Forfatter');
@define('LAST_UPDATED', 'Sidst opdateret');
@define('TRACKBACK_SPECIFIC', 'Trackback URI til denne artikel');
@define('DIRECT_LINK', 'Direkte link til denne artikel');
@define('COMMENT_ADDED', 'Din kommentar blev tilføjet. ');
@define('COMMENT_ADDED_CLICK', 'Klik %her for at gå tilbage%s til kommentarerne, og %sher for at lukke%s dette vindue.');
@define('COMMENT_NOT_ADDED_CLICK', 'Klik %sher for at gå tilbage%s til kommentarene, og %sher for at lukke%s dette vindue. ');
@define('COMMENTS_DISABLE', 'Tillad ikke kommentarer til denne artikel');
@define('COMMENTS_ENABLE', 'Tillad kommentarer til denne artikel');
@define('COMMENTS_CLOSED', 'Forfatteren har valgt ikke at tillade kommentarer til denne artikel');
@define('EMPTY_COMMENT', 'Din kommentar indeholdt ikke noget, gå venligst %stilbage%s og prøv igen');
@define('ENTRIES_FOR', 'Artikler fra %s');
@define('DOCUMENT_NOT_FOUND', 'Dokumentet %s kunne ikke findes.');
@define('USERNAME', 'Brugernavn');
@define('PASSWORD', 'Adgangskode');
@define('AUTOMATIC_LOGIN', 'Gem oplysningerne');
@define('SERENDIPITY_INSTALLATION', 'Serendipity installation');
@define('LEFT', 'venstre');
@define('RIGHT', 'højre');
@define('HIDDEN', 'skjult');
@define('REMOVE_TICKED_PLUGINS', 'Fjern valgte plugins');
@define('SAVE_CHANGES_TO_LAYOUT', 'Gem layout-ændringerne');
@define('COMMENTS_FROM', 'Kommentar fra');
@define('ERROR', 'Fejl');
@define('ENTRY_SAVED', 'Din artikel blev gemt');
@define('DELETE_SURE', 'Er du sikker på du vil slette #%s permanent?');
@define('NOT_REALLY', 'Egentlig ikke...');
@define('DUMP_IT', 'Smid den ud!');
@define('RIP_ENTRY', 'Farvel artikel #%s');
@define('CATEGORY_DELETED_ARTICLES_MOVED', 'Kategori #%s blev slettet. Gamle artikler flyttet til kategori #%s');
@define('CATEGORY_DELETED', 'Kategori #%s blev slettet.');
@define('INVALID_CATEGORY', 'Ingen kategori blev valgt til sletning');
@define('CATEGORY_SAVED', 'Kategori gemt');
@define('SELECT_TEMPLATE', 'Vælg den skabelon du ønsker at bruge til din blog');
@define('ENTRIES_NOT_SUCCESSFULLY_INSERTED', 'Der var problemer under indsættelsen af artiklerne!');
@define('YES', 'Ja');
@define('NO', 'Nej');
@define('USE_DEFAULT', 'Default');
@define('CHECK_N_SAVE', 'Check &amp; gem');
@define('DIRECTORY_WRITE_ERROR', 'Kan ikke skrive til biblioteket %s. Check filrettighederne.');
@define('DIRECTORY_CREATE_ERROR', 'Biblioteket %s eksisterer ikke og kunne ikke oprettes. Opret venligst biblioteket manuelt');
@define('DIRECTORY_RUN_CMD', '&nbsp;-&gt; Kør <i>%s %s</i>');
@define('CANT_EXECUTE_BINARY', 'Kan ikke eksekvere %s');
@define('FILE_WRITE_ERROR', 'Kan ikke skrive til filen %s.');
@define('FILE_CREATE_YOURSELF', 'Opret venligst filen selv og check dens rettigheder');
@define('COPY_CODE_BELOW', '<br />* Kopier blot koden nedenunder og placer den i %s i din %s mappe:<b><pre>%s</pre></b>' . "\n");
@define('WWW_USER', 'Ændr www til den bruger som apache kører som (fx. nobody).');
@define('BROWSER_RELOAD', 'Når du har gjort dette, så tryk på browserens "opdater" knap');
@define('DIAGNOSTIC_ERROR', 'Vi har opdaget nogle fejl mens vi kørte nogle diagnostiker på dine indtastede informationer:');
@define('SERENDIPITY_NOT_INSTALLED', 'Serendipity er endnu ikke installeret. Klik <a href="%s">her for at installere</a> nu.');
@define('INCLUDE_ERROR', 'serendipityfejl: Kunne ikke inkludere %s - Afbryder.');
@define('DATABASE_ERROR', 'serendipityfejl: Kunne ikke oprette forbindelse til databasen - Afbryder.');
@define('CREATE_DATABASE', 'Opretter standarddatabase setup...');
@define('ATTEMPT_WRITE_FILE', 'Forsøger at skrive til %s ...');
@define('WRITTEN_N_SAVED', 'Konfiguration skrevet &amp; gemt');
@define('IMAGE_ALIGNMENT', 'Billedejustering');
@define('ENTER_NEW_NAME', 'Indtast det nye navn for: ');
@define('RESIZING', 'Ændre dimensioner');
@define('RESIZE_DONE', 'Færdig (Ændrede %s billeder).');
@define('SYNCING', 'Synkroniserer databasen med billedemappen');
@define('SYNC_DONE', 'Færdig (Synkroniserede %s billeder).');
@define('DELETE_IMAGE_FAIL' , 'Kunne ikke slette billedet <b>%s</b>');
@define('DELETE_THUMBNAIL', 'Slettede billedet ved navn <b>%s</b>');
@define('FILE_NOT_FOUND', 'Kunne ikke finde filen ved navn <b>%s</b>, måske er den allerede slettet?');
@define('ABORT_NOW', 'Afbryd nu');
@define('REMOTE_FILE_NOT_FOUND', 'Filen kunne ikke findes på serveren, er du sikker på URLen: <b>%s</b> er korrekt?');
@define('FILE_FETCHED', '%s hentet: %s');
@define('FILE_UPLOADED', 'Filen %s er blevet uploadet: %s');
@define('WORD_OR', 'eller');
@define('SCALING_IMAGE', 'Ændre størrelsen på %s til %s x %s px');
@define('KEEP_PROPORTIONS', 'Bevar forholdet');
@define('REALLY_SCALE_IMAGE', 'Er du sikker på du vil ændre størrelsen på dette billede? Der er ingen vej tilbage!');
@define('TOGGLE_ALL', 'Vis/Skjul alle');
@define('TOGGLE_OPTION', 'Vis/Skjul denne option');
@define('SUBSCRIBE_TO_THIS_ENTRY', 'Abonnér på denne artikel');
@define('UNSUBSCRIBE_OK', "%s er ikke længere abonnement på denne artikel");
@define('NEW_COMMENT_TO_SUBSCRIBED_ENTRY', 'Ny kommentar på abonnerede artikel "%s"');
@define('SUBSCRIPTION_MAIL', "Hej %s,\n\nEn ny kommentar er blevet lavet til en artikel du abonnerer på hos \"%s\", ved navn \"%s\"\nNavnet på skribenten er: %s\n\nDu kan finde artiklen her: %s\n\nDu kan stoppe dit abonnement ved at klikke på dette link: %s\n");
@define('SUBSCRIPTION_TRACKBACK_MAIL', "Hej %s,\n\nEt nyt trackback er blevet lavet til en artikel du abonnerer på hos \"%s\", ved navn \"%s\"\nNavnet på skribenten er: %s\n\nDu kan finde artiklen her: %s\n\nDu kan stoppe dit abonnement ved at klikke på dette link: %s\n");
@define('SIGNATURE', "\n-- \n%s bruger Serendipity.\nDen bedste blog på nettet, du kan også bruge den.\nKig nærmere på <http://s9y.org> for at finde mere information.");
@define('SYNDICATION_PLUGIN_091', 'RSS 0.91 feed');
@define('SYNDICATION_PLUGIN_10', 'RSS 1.0 feed');
@define('SYNDICATION_PLUGIN_20', 'RSS 2.0 feed');
@define('SYNDICATION_PLUGIN_20c', 'RSS 2.0 kommentarer');
@define('SYNDICATION_PLUGIN_ATOM03', 'ATOM 0.3 feed');
@define('SYNDICATION_PLUGIN_GENERIC_FEED', '%s feed');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR', 'Feltet "Hovedredaktør"');
@define('SYNDICATION_PLUGIN_WEBMASTER',  'Feltet "webmaster"');
@define('SYNDICATION_PLUGIN_BANNERURL', 'Billede til RSS feedet');
@define('SYNDICATION_PLUGIN_BANNERWIDTH', 'Billedebredde');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT', 'Billedehøjde');
@define('SYNDICATION_PLUGIN_WEBMASTER_DESC',  'Email adressen på webmasteren, hvis tilgængelig. (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_MANAGINGEDITOR_DESC', 'E-mail adressen på redaktøren, hvis tilgængelig. (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_BANNERURL_DESC', 'URL på et billede i GIF/JPEG/PNG format, hvis tilgængeligt. (tom: serendipity-logo)');
@define('SYNDICATION_PLUGIN_BANNERWIDTH_DESC', 'i pixels, max. 144');
@define('SYNDICATION_PLUGIN_BANNERHEIGHT_DESC', 'i pixels, max. 400');
@define('SYNDICATION_PLUGIN_TTL', 'Feltet "ttl" (time-to-live)');
@define('SYNDICATION_PLUGIN_TTL_DESC', 'Antallet af minutter din blog skal gemmes af eksterne sider/programmer (tom: skjult) [RSS 2.0]');
@define('SYNDICATION_PLUGIN_PUBDATE', 'Feltet "pubDate"');
@define('SYNDICATION_PLUGIN_PUBDATE_DESC', 'Skal "pubDate"-feltet være indkapslet til en RSS-channel, for at vise datoen på den nyeste artikel?');
@define('CONTENT', 'Indhold');
@define('TYPE', 'Type');
@define('DRAFT', 'Udkast');
@define('PUBLISH', 'Udgiv');
@define('PREVIEW', 'Vis');
@define('DATE', 'Dato');
@define('DATE_FORMAT_2', 'Y-m-d H:i'); // Needs to be ISO 8601 compliant for date conversion!
@define('DATE_INVALID', 'Advarsel: Den dato du indtastede var ugyldig. Det skal indtastes i følgende format: YYYY-MM-DD HH:MM.');
@define('CATEGORY_PLUGIN_DESC', 'Viser listen over kategorier.');
@define('ALL_AUTHORS', 'Alle forfattere');
@define('CATEGORIES_TO_FETCH', 'Kategorier som skal hentes');
@define('CATEGORIES_TO_FETCH_DESC', 'Hent kategorier fra en bestemt forfatter?');
@define('PAGE_BROWSE_ENTRIES', 'Side %s af %s, i alt %s artikler');
@define('PREVIOUS_PAGE', 'forrige side');
@define('NEXT_PAGE', 'næste side');
@define('ALL_CATEGORIES', 'Alle kategorier');
@define('DO_MARKUP', 'Udført Markup-transformation');
@define('GENERAL_PLUGIN_DATEFORMAT', 'Datoformat');
@define('GENERAL_PLUGIN_DATEFORMAT_BLAHBLAH', 'Formatet på artiklens faktiske dato, brug PHPs strftime() variabler. (Standard: "%s")');
@define('ERROR_TEMPLATE_FILE', 'Kunne ikke åbne skabelonen, opdater Serendipity!');
@define('ADVANCED_OPTIONS', 'Avancerede indstillinger');
@define('EDIT_ENTRY', 'Rediger artikel');
@define('HTACCESS_ERROR', 'For at kunne checke din lokale webserver\'s installation, skal Serendipity være i stand til at skrive til filen ".htaccess". Dette var ikke muligt pga. forkerte rettigheder. Justér rettighederne således: <br />&nbsp;&nbsp;%s<br />og genindlæs siden.');
@define('SORT_ORDER', 'Sorter efter');
@define('SORT_ORDER_NAME', 'Filnavn');
@define('SORT_ORDER_EXTENSION', 'Filtype');
@define('SORT_ORDER_SIZE', 'Filstørrelse');
@define('SORT_ORDER_WIDTH', 'Billedebrede');
@define('SORT_ORDER_HEIGHT', 'Billedehøjde');
@define('SORT_ORDER_DATE', 'Upload-dato');
@define('SORT_ORDER_ASC', 'Stigende');
@define('SORT_ORDER_DESC', 'Faldende');
@define('THUMBNAIL_SHORT', 'Mini');
@define('ORIGINAL_SHORT', 'Orig.');
@define('APPLY_MARKUP_TO', 'Formater %s');
@define('CALENDAR_BEGINNING_OF_WEEK', 'Starten på ugen');
@define('SERENDIPITY_NEEDS_UPGRADE', 'Serendipity har opdaget at din nuværende konfiguration passer til version %s. Serendipity selv er installeret som version %s, Det er nødvendigt at opgradere! <a href="%s">Klik her!</a>');
@define('SERENDIPITY_UPGRADER_WELCOME', 'Velkommen til Serendipitys opgraderingsscript.');
@define('SERENDIPITY_UPGRADER_PURPOSE', 'Scriptet vil hjælpe dig med at opgradere Serendipity %s.');
@define('SERENDIPITY_UPGRADER_WHY', 'Denne meddelelse vises, fordi Serendipity er installeret med version %s, men databasen er endnu ikke opgraderet til denne version.');
@define('SERENDIPITY_UPGRADER_DATABASE_UPDATES', 'Database opdateringer (%s)');
@define('SERENDIPITY_UPGRADER_FOUND_SQL_FILES', 'Følgende .sql-filer skal eksekveres før Serendipity igen kan fungere normalt.');
@define('SERENDIPITY_UPGRADER_VERSION_SPECIFIC',  'Versionsspecifikke opgaver');
@define('SERENDIPITY_UPGRADER_NO_VERSION_SPECIFIC', 'Ingen versionsspecifikke opgaver fundet');
@define('SERENDIPITY_UPGRADER_PROCEED_QUESTION', 'Ønsker du at ovenstående opgaver udføres?');
@define('SERENDIPITY_UPGRADER_PROCEED_ABORT', 'Nej, jeg udfører dem manuelt');
@define('SERENDIPITY_UPGRADER_PROCEED_DOIT', 'Ja tak!');
@define('SERENDIPITY_UPGRADER_NO_UPGRADES', 'Det ser ud til at opgradering ikke er nødvendig.');
@define('SERENDIPITY_UPGRADER_CONSIDER_DONE', 'Serendipity er opgraderet');
@define('SERENDIPITY_UPGRADER_YOU_HAVE_IGNORED', 'Du har ignoreret en del af opgraderingen. Undersøg venligst om databasen er korrekt opdateret, og planlagte opgaver udført');
@define('SERENDIPITY_UPGRADER_NOW_UPGRADED', 'Din Serendipity-installation er nu opgraderet til version %s');
@define('SERENDIPITY_UPGRADER_RETURN_HERE', 'Du kan vende tilbage til din blog ved at klikke %sher%s');
@define('MANAGE_USERS', 'Håndter brugerer');
@define('CREATE_NEW_USER', 'Opret by bruger');
@define('CREATE_NOT_AUTHORIZED', 'Du kan ikke redigere brugere med den samme brugerniveau som digselv');
@define('CREATE_NOT_AUTHORIZED_USERLEVEL', 'Du kan ikke oprette brugere med en højere brugerniveau end digselv');
@define('CREATED_USER', 'En ny bruger %s er blevet oprettet');
@define('MODIFIED_USER', 'Egenskaberne for brugeren %s er blevet ændret');
@define('USER_LEVEL', 'brugerniveau');
@define('DELETE_USER', 'Du er ved at slette bruger #%d %s. Er du sikker? Dette vil forhindre visning af alle artikler skrevet af ham.');
@define('DELETED_USER', 'Bruger #%d %s er blevet slettet.');
@define('LIMIT_TO_NUMBER', 'Hvor mange punkter skal vises?');
@define('ENTRIES_PER_PAGE', 'artikler per side');
@define('PERMISSIONS', 'Rettigheder');

/* DATABASE SETTINGS */
@define('INSTALL_CAT_DB', 'Database indstillinger');
@define('INSTALL_CAT_DB_DESC', 'Her kan du indtaste dine database indstillinger');
@define('INSTALL_DBTYPE', 'Database type');
@define('INSTALL_DBTYPE_DESC', 'Database type');
@define('INSTALL_DBHOST', 'Database host');
@define('INSTALL_DBHOST_DESC', 'Hostnavn til din database server');
@define('INSTALL_DBUSER', 'Database bruger');
@define('INSTALL_DBUSER_DESC', 'Brugernavnet der er brugt til at forbinde til din database');
@define('INSTALL_DBPASS', 'Database adgangskode');
@define('INSTALL_DBPASS_DESC', 'Adgangskoden der passer til ovenstående brugernavn');
@define('INSTALL_DBNAME', 'Database navn');
@define('INSTALL_DBNAME_DESC', 'Navnet på din database');
@define('INSTALL_DBPREFIX', 'Database tabel præfix');
@define('INSTALL_DBPREFIX_DESC', 'Præfix på tabelnavne, fx. serendipity_');

/* PATHS */
@define('INSTALL_CAT_PATHS', 'Stier');
@define('INSTALL_CAT_PATHS_DESC', 'Forskellige stier til forskellige essentielle mapper og filer. Glem ikke efterfølgende slashes på biblioteker!');
@define('INSTALL_FULLPATH', 'Fuld sti');
@define('INSTALL_FULLPATH_DESC', 'Den absolutte sti til din serendipity installation');
@define('INSTALL_UPLOADPATH', 'Upload sti');
@define('INSTALL_UPLOADPATH_DESC', 'Alle uploads bliver placeret her, relativ til \'Fuld sti\' - typisk \'uploads/\'');
@define('INSTALL_RELPATH', 'Relativ sti');
@define('INSTALL_RELPATH_DESC', 'Sti til Serendipity i henhold til din browser, typisk \'/serendipity/\'');
@define('INSTALL_RELTEMPLPATH', 'Relativ skabelon sti');
@define('INSTALL_RELTEMPLPATH_DESC', 'Stien til mappen der indeholder dine skabeloner - Relativ til \'Relativ sti\'');
@define('INSTALL_RELUPLOADPATH', 'Relativ upload sti');
@define('INSTALL_RELUPLOADPATH_DESC', 'Sti til dine uploads i henhold til din browser - Relativ til \'Relativ sti\'');
@define('INSTALL_URL', 'URL til din blog');
@define('INSTALL_URL_DESC', 'Grund URL for din Serendipity installation');
@define('INSTALL_INDEXFILE', 'Index fil');
@define('INSTALL_INDEXFILE_DESC', 'Navnet på din Serendipity index fil');

/* Generel settings */
@define('INSTALL_CAT_SETTINGS', 'Generelle indstillinger');
@define('INSTALL_CAT_SETTINGS_DESC', 'Tilpas den måde Serendipity opfører sig på');
@define('INSTALL_USERNAME', 'Admin brugernavn');
@define('INSTALL_USERNAME_DESC', 'Brugernavn til admin login');
@define('INSTALL_PASSWORD', 'Admin adgangskode');
@define('INSTALL_PASSWORD_DESC', 'Adgangskode til admin login');
@define('INSTALL_EMAIL', 'Admin email');
@define('INSTALL_EMAIL_DESC', 'E-mail adresse på ejeren af bloggen');
@define('INSTALL_SENDMAIL', 'Send mails til admin?');
@define('INSTALL_SENDMAIL_DESC', 'Vil du modtage emails når kommentare er givet på dine artikler?');
@define('INSTALL_SUBSCRIBE', 'Tillad brugere at abonnere på artikler?');
@define('INSTALL_SUBSCRIBE_DESC', 'Tillad brugere at abonnere på en artikel og derved modtage en mail når der bliver oprettet nye kommentare på den artikel');
@define('INSTALL_BLOGNAME', 'Navn på blog');
@define('INSTALL_BLOGNAME_DESC', 'Titlen på din blog');
@define('INSTALL_BLOGDESC', 'Blog beskrivelse');
@define('INSTALL_BLOGDESC_DESC', 'Beskrivelse af din blog');
@define('INSTALL_LANG', 'Sprog');
@define('INSTALL_LANG_DESC', 'Vælg sproget på din blog');

/* Appearance and options */
@define('INSTALL_CAT_DISPLAY', 'Udseende og indstillinger');
@define('INSTALL_CAT_DISPLAY_DESC', 'Tilpas hvordan Serendipity ser ud og føles');
@define('INSTALL_WYSIWYG', 'Brug WYSIWYG editor');
@define('INSTALL_WYSIWYG_DESC', 'Vil du benytte WYSIWYG editoren? (Virker med IE5+, delvis i Mozilla 1.3+)');
@define('INSTALL_XHTML11', 'Gennemtving XHTML 1.1');
@define('INSTALL_XHTML11_DESC', 'Ønsker du at gennemtvinge XHTML 1.1 overholdelse (Kan skabe problemer i 4. generations browsere)');
@define('INSTALL_POPUP', 'Aktiver brug af popup vinduer');
@define('INSTALL_POPUP_DESC', 'Vil du åbne kommentarer og trackbacks i et popup vindue?');
@define('INSTALL_EMBED', 'Er Serendipity embedded?');
@define('INSTALL_EMBED_DESC', 'Hvis du ønsker at indkapsle Serendipity inde i en normal side, aktiver da dette direktiv for at ignorere headers og kun udskrive indholdet. Du kan benytte indexFile direktivet til at lave en wrapper fil hvor du placere din normale hjemmeside headers. Konsulter README filen for mere information!');
@define('INSTALL_TOP_AS_LINKS', 'Vis top udgangssider/referencer som links?');
@define('INSTALL_TOP_AS_LINKS_DESC', '"Nej": Udgangs- og henvisende sider er vist som ren tekst for at undgå google spam. "Ja": Udgangs- og henvisende sider er vist som hyperlinks. "standard": Brug indstillinger fra global konfiguration (anbefalet).');
@define('INSTALL_BLOCKREF', 'Bloker referencer');
@define('INSTALL_BLOCKREF_DESC', 'Er der nogle specielle hosts du ikke ønsker skal vises i reference listen? Separer listen af hostnavne med \';\' og bemærk at disse er blokere med substring masker!');
@define('INSTALL_REWRITE', 'URL Omskrivning');
@define('INSTALL_REWRITE_DESC', 'Vælg hvilken regel du ønsker at bruge når du generere URL\'er. Aktivering af omskrivningsregler vil gøre dine URL\'er flotte og gøre din side bedre at indeksere for robotter som google. Webserveren skal enten understøtte mod_rewrite eller "AllowOverride All" for dit Serendipity bibliotek. Standardindstillingen er automatisk beregnet');

/* Imageconversion Settings */
@define('INSTALL_CAT_IMAGECONV', 'Billedekonverterings indstillinger');
@define('INSTALL_CAT_IMAGECONV_DESC', 'Generel information om hvordan Serendipity skal håndtere billeder');
@define('INSTALL_IMAGEMAGICK', 'Brug Imagemagick');
@define('INSTALL_IMAGEMAGICK_DESC', 'Har du image magick installeret og ønsker at bruge det til at ændre størrelse på billeder?');
@define('INSTALL_IMAGEMAGICKPATH', 'Sti til convert binær fil');
@define('INSTALL_IMAGEMAGICKPATH_DESC', 'Fuld sti og navn på din image magick convert binær fil');
@define('INSTALL_THUMBSUFFIX', 'Thumbnail suffiks');
@define('INSTALL_THUMBSUFFIX_DESC', 'Thumbnails vil blive navngivet i følgende format: original.[suffix].ext');
@define('INSTALL_THUMBWIDTH', 'Thumbnail dimensioner');
@define('INSTALL_THUMBWIDTH_DESC', 'Statisk maximal brede på et auto-genereret thumbnail');

/* Personal details */
@define('USERCONF_CAT_PERSONAL', 'Dine personlige detaljer');
@define('USERCONF_CAT_PERSONAL_DESC', 'Ændre dine personlige detaljer');
@define('USERCONF_USERNAME', 'Dit brugernavn');
@define('USERCONF_USERNAME_DESC', 'Brugernavnet du vil bruge for at logge ind i bloggen');
@define('USERCONF_PASSWORD', 'Dit kodeord');
@define('USERCONF_PASSWORD_DESC', 'Kodeordet du vil bruge for at logge ind i bloggen');
@define('USERCONF_EMAIL', 'Din email adresse');
@define('USERCONF_EMAIL_DESC', 'Din personlige email adresse');
@define('USERCONF_SENDCOMMENTS', 'Send beskeder om nye kommentarer?');
@define('USERCONF_SENDCOMMENTS_DESC', 'Ønsker du at modtage en mail når nye kommentarer bliver lavet på dine artikler?');
@define('USERCONF_SENDTRACKBACKS', 'Send beskeder om nye trackbacks?');
@define('USERCONF_SENDTRACKBACKS_DESC', 'Ønsker du at modtage en mail når nye trackbacks bliver lavet på dine artikler?');
@define('USERCONF_ALLOWPUBLISH', 'Tilladelse: Udgiv artikler?');
@define('USERCONF_ALLOWPUBLISH_DESC', 'Kan denne bruger udgive artikler?');

@define('DIRECTORIES_AVAILABLE', 'I listen over tilgængelige undermapper, kan du klikke på en ny mappe for at oprette en ny mappe inden for den stuktur.');
@define('ALL_DIRECTORIES', 'alle mapper');
@define('MANAGE_DIRECTORIES', 'Håndtér mapper');
@define('DIRECTORY_CREATED', 'Mappen <strong>%s</strong> er blevet oprettet.');
@define('PARENT_DIRECTORY', 'Hovedmappe');
@define('CONFIRM_DELETE_DIRECTORY', 'Er du sikker på du vil slette al indholdet af mappen %s?');
@define('ERROR_NO_DIRECTORY', 'Fejl: Mappen %s eksistere ikke');
@define('CHECKING_DIRECTORY', 'Checker filer i mappen %s');
@define('DELETING_FILE', 'Sletter fil %s...');
@define('ERROR_DIRECTORY_NOT_EMPTY', 'Kunne ikke fjerne en ikke-tom mappe. Afkryds "gennemtving sletning" feltet, hvis du vil slette disse og tryk derefter på submit igen. Eksisterende filer er:');
@define('DIRECTORY_DELETE_FAILED', 'Sletning af mappe %s mislykkedes. Check rettigheder eller ovenstående beskeder.');
@define('DIRECTORY_DELETE_SUCCESS', 'Mappen %s er blevet slettet.');
@define('SKIPPING_FILE_EXTENSION', 'Ignorerede filen: Manglende filtype %s.');
@define('SKIPPING_FILE_UNREADABLE', 'Ignorere fil: %s er ikke læsbar.');
@define('FOUND_FILE', 'Fandt ny/ændret fil: %s.');
@define('ALREADY_SUBCATEGORY', '%s er allerede en underkategori af %s.');
@define('PARENT_CATEGORY', 'Overkategori');
@define('IN_REPLY_TO', 'Som svar på');
@define('TOP_LEVEL', 'Topniveau');
@define('XML_IMAGE_TO_DISPLAY', 'XML knap');
@define('XML_IMAGE_TO_DISPLAY_DESC','Links til XML Feeds vil blive vist med dette billede. Efterlad tomt for standard, indtast \'none\' for at deaktivere.');
@define('SUCCESS', 'Succes');
@define('NUMBER_FORMAT_DECIMALS', '2');
@define('NUMBER_FORMAT_DECPOINT', ',');
@define('NUMBER_FORMAT_THOUSANDS', '.');
@define('POWERED_BY_SHOW_TEXT', 'Vis "Serendipity" som tekst');
@define('POWERED_BY_SHOW_TEXT_DESC', 'Vil vise "Serendipity Weblog" som tekst');
@define('POWERED_BY_SHOW_IMAGE', 'Vis "Serendipity"" som et logo');
@define('POWERED_BY_SHOW_IMAGE_DESC', 'Vis Serendipity logoet');
@define('SETTINGS_SAVED_AT', 'De nye indstillinger er blevet gemt kl %s');
@define('PLUGIN_ITEM_DISPLAY', 'Hvor skal enheden vises?');
@define('PLUGIN_ITEM_DISPLAY_EXTENDED', 'Kun udvidet artikel');
@define('PLUGIN_ITEM_DISPLAY_OVERVIEW', 'Kun i oversigten');
@define('PLUGIN_ITEM_DISPLAY_BOTH', 'Hele tiden');
@define('RSS_IMPORT_CATEGORY', 'Brug denne kategori for kategoriløse artikler');
@define('ERROR_UNKNOWN_NOUPLOAD', 'Der skete en ukendt fejl, filen blev ikke uploaded. Måske er din filstørrelse større end den maximale størrelse tilladt af din serveropsætning. Spørg din webudbyder eller rediger din php.ini fil for at tillade uploads af større filer.');
@define('COMMENTS_WILL_BE_MODERATED', 'Kommentarer til denne artikel skal modereres før de vil blive vist.');
@define('YOU_HAVE_THESE_OPTIONS', 'Du har følgende muligheder:');
@define('THIS_COMMENT_NEEDS_REVIEW', 'Advarsel: Denne kommentar kræver godkendelse førend den vil blive vist');
@define('DELETE_COMMENT', 'Slet kommentar');
@define('APPROVE_COMMENT', 'Godkend kommentar');
@define('REQUIRES_REVIEW', 'Kræver godkendelse');
@define('COMMENT_APPROVED', 'Kommentar #%s er blevet godkendt');
@define('COMMENT_DELETED', 'Kommentar #%s er blevet slettet');
@define('VIEW', 'Vis');
@define('COMMENT_ALREADY_APPROVED', 'Kommentar #%s ser allerede ud til at være godkendt');
@define('COMMENT_EDITED', 'Den valgte kommentar er blevet redigeret');
@define('HIDE', 'Skjul');
@define('VIEW_EXTENDED_ENTRY', 'Læs resten af "%s"');
@define('TRACKBACK_SPECIFIC_ON_CLICK', 'Dette link er ikke ikke til at blive klikket. Det indeholder denne artikels trackback URI. Du kan bruge denne URI til at sende ping- & trackbacks fra din egen blog til denne artikel. For at kopiere linket, kan du højreklikke og vælge "Kopier genvej" i Internet Explorer eller "Copy Link Location" i Mozilla.');
@define('THIS_TRACKBACK_NEEDS_REVIEW', 'Advarsel: Dette trackback kræver godkendelse førend det vil blive vist');
@define('DELETE_TRACKBACK', 'Slet trackback');
@define('APPROVE_TRACKBACK', 'Godkend trackback');
@define('TRACKBACK_APPROVED', 'Trackback #%s er blevet godkendt');
@define('TRACKBACK_DELETED', 'Trackback #%s er blevet slettet');
@define('COMMENTS_MODERATE', 'Kommentarer og trackbacks til denne artikel kræver moderering');
@define('PLUGIN_SUPERUSER_HTTPS', 'Brug https til login');
@define('PLUGIN_SUPERUSER_HTTPS_DESC', 'Lader loginlinket pege på en https-destination. Din webserver skal understøtte dette!');
@define('INSTALL_SHOW_EXTERNAL_LINKS', 'Gør eksterne links klikbare?');
@define('INSTALL_SHOW_EXTERNAL_LINKS_DESC', '"nej": Eksterne links (Top udgangsider, Top henvisninger, bruger kommentarer) er ikke vist/vist som ren tekst hvor brugbart, for at forhindre google spam (anbefales). "ja": Eksterne links er vist som hyperlinks. Kan overskrives inde i hver enkel sidebar plugin konfigurationen!');
@define('PAGE_BROWSE_COMMENTS', 'Side %s af %s, i alt %s kommentarer');
@define('FILTERS', 'Filtrer');
@define('FIND_ENTRIES', 'Find artikler');
@define('FIND_COMMENTS', 'Find kommentarer');
@define('FIND_MEDIA', 'Find media');
@define('FILTER_DIRECTORY', 'Bibliotek');
@define('SORT_BY', 'Sorter efter');
@define('TRACKBACK_COULD_NOT_CONNECT', 'Intet trackback sendt: Kunne ikke åbne forbindelse til %s på port %d');
@define('MEDIA', 'Media');
@define('MEDIA_LIBRARY', 'Mediabibliotek');
@define('ADD_MEDIA', 'Tilføj media');
@define('ENTER_MEDIA_URL', 'Indtast en URL til filen du vil hente');
@define('ENTER_MEDIA_UPLOAD', 'Vælg en fil du ønsker at uploade:');
@define('SAVE_FILE_AS', 'Gem fil som:');
@define('STORE_IN_DIRECTORY', 'Gem i følgende bibliotek:');
@define('MEDIA_RENAME', 'Omdøb denne fil');
@define('IMAGE_RESIZE', 'Ændre størrelse på billede');
@define('MEDIA_DELETE', 'Slet denne fil');
@define('FILES_PER_PAGE', 'Filer per side');
@define('CLICK_FILE_TO_INSERT', 'Klik på filen du vil indsætte:');
@define('SELECT_FILE', 'Vælg filen du vil indsætte');
@define('MEDIA_FULLSIZE', 'Fuld størrelse');
@define('CALENDAR_BOW_DESC', 'Dagen i ugen der skal bruges som den første dag i ugen. Standardværdien er Mandag');
@define('SUPERUSER', 'Blog Administration');
@define('ALLOWS_YOU_BLAHBLAH', 'Placerer et link i sidebaren til din blog administration');
@define('CALENDAR', 'Kalender');
@define('SUPERUSER_OPEN_ADMIN', 'Åbn administration');
@define('SUPERUSER_OPEN_LOGIN', 'Åbn loginskærm');
@define('INVERT_SELECTIONS', 'Inverter valgte elementer');
@define('COMMENTS_DELETE_CONFIRM', 'Er du sikker på du vil slette de valgte kommentarer?');
@define('COMMENT_DELETE_CONFIRM', 'Er du sikker på du vil slette kommentar #%d, skrevet af %s?');
@define('DELETE_SELECTED_COMMENTS', 'Slet valgte kommentarer');
@define('VIEW_COMMENT', 'Vis kommentar');
@define('VIEW_ENTRY', 'Vis artikel');
@define('DELETE_FILE', 'Slettede filen ved navn <b>%s</b>');
@define('ABOUT_TO_DELETE_FILE', 'Du er ved at slette <b>%s</b><br />Hvis du benytter denne fil i nogle af dine artikler, vil det resultere i døde links eller billeder<br />Er du sikker på du vil fortsætte?<br /><br />');
@define('TRACKBACK_SENDING', 'Sender trackback til URI %s...');
@define('TRACKBACK_SENT', 'Trackback fuldført');
@define('TRACKBACK_FAILED', 'Trackback fejl: %s');
@define('TRACKBACK_NOT_FOUND', 'Ingen trackback URI fundet.');
@define('TRACKBACK_URI_MISMATCH', 'Den automastiske trackback URI passer ikke vores egen URI.');
@define('TRACKBACK_CHECKING', 'Checker <u>%s</u> for mulige trackbacks...');
@define('TRACKBACK_NO_DATA', 'Modstående side indeholdte inden data');
@define('TRACKBACK_SIZE', 'Modstående URI overskred den maximale filstørrelse på %s bytes.');
@define('VIEWMODE_THREADED', 'Skift til trådet visning');
@define('COMMENTS_VIEWMODE_THREADED', 'Tråde');
@define('COMMENTS_VIEWMODE_LINEAR', 'Linear');
@define('DISPLAY_COMMENTS_AS', 'Vis kommentarer som');
@define('SIDEBAR_PLUGINS', 'Sidebarplugins');
@define('EVENT_PLUGINS', 'Hændelseplugins');
@define('ADD_MEDIA_BLAHBLAH', '<b>Tilføj en fil til dit mediearkiv:</b><p>Her kan du uploade mediafiler, eller få dem hentet fra et sted på nettet. Hvis du ikke har et passende billeder, <a href="http://images.google.com" target="_blank">prøv at søg efter billeder på google</a> der passer til dine tanker, resultatet er ofte brugbart og sjovt :)</p><p><b>Vælg metode:</b></p><br/>');
@define('COMMENTS_FILTER_SHOW', 'Vis');
@define('COMMENTS_FILTER_ALL', 'Alle');
@define('COMMENTS_FILTER_APPROVED_ONLY', 'Kun godkendte');
@define('COMMENTS_FILTER_NEED_APPROVAL', 'Afventer godkendelse');
@define('RSS_IMPORT_BODYONLY', 'Placer al den importeret tekst ind i "artikel" delen, og ikke opdelt ind i "udvidet artikel" sektionen.');
@define('SYNDICATION_PLUGIN_FULLFEED', 'Vis hele artiklen, med udvidet del, inde i RSS feed');
@define('MT_DATA_FILE', 'MovableType data fil');
@define('FORCE', 'gennemtving');
@define('CREATE_AUTHOR', 'Opret forfatter \'%s\'.');
@define('CREATE_CATEGORY', 'Opret kategori \'%s\'.');
@define('MYSQL_REQUIRED', 'Du skal have MySQL udvidelsen installere førend du kan udføre denne handling.');
@define('COULDNT_CONNECT', 'Kunne ikke forbinde til MySQL database: %s.');
@define('COULDNT_SELECT_DB', 'Kunne ikke vælge database: %s.');
@define('COULDNT_SELECT_USER_INFO', 'Kunne ikke finde bruger information: %s.');
@define('COULDNT_SELECT_CATEGORY_INFO', 'Kunne ikke finde kategori information: %s.');
@define('COULDNT_SELECT_ENTRY_INFO', 'Kunne ikke finde artikel information: %s.');
@define('COULDNT_SELECT_COMMENT_INFO', 'Kunne ikke finde kommentar information: %s.');
@define('WEEK', 'Uge');
@define('WEEKS', 'Uger');
@define('MONTHS', 'Månder');
@define('DAYS', 'Dage');
@define('ARCHIVE_FREQUENCY', 'Kalender frekvens');
@define('ARCHIVE_FREQUENCY_DESC', 'Angiver intervallet imellem hvert punkt på listen');
@define('ARCHIVE_COUNT', 'Antal punkter på listen');
@define('ARCHIVE_COUNT_DESC', 'Det totale antal af måneder, uger eller dage at vise');
@define('BELOW_IS_A_LIST_OF_INSTALLED_PLUGINS', 'Herunder er en liste over installerede plugins');
@define('SIDEBAR_PLUGIN', 'sidebar plugin');
@define('EVENT_PLUGIN', 'event plugin');
@define('CLICK_HERE_TO_INSTALL_PLUGIN', 'Klik her for at installere et nyt %s');
@define('VERSION', 'version');
@define('INSTALL', 'Installer');
@define('ALREADY_INSTALLED', 'Allerede installeret');
@define('SELECT_A_PLUGIN_TO_ADD', 'Vælg det plugin du ønsker at installere');
@define('INSTALL_OFFSET', 'Server tidsforskydelse');
@define('STICKY_POSTINGS', 'Vedvarende artikler');
@define('INSTALL_FETCHLIMIT', 'Artikler på forsiden');
@define('INSTALL_FETCHLIMIT_DESC', 'Antallet af artikler at vise på hver side på forsiden');
@define('IMPORT_ENTRIES', 'Importer data');
@define('EXPORT_ENTRIES', 'Eksporter artikler');
@define('IMPORT_WELCOME', 'Velkommen til Serendipity importværktøj');
@define('IMPORT_WHAT_CAN', 'Her kan du importere artikler fra andre weblog software applikationer');
@define('IMPORT_SELECT', 'Vælg venligst det software du ønsker at importere fra');
@define('IMPORT_PLEASE_ENTER', 'Indtast venligst de påkrævede data herunder');
@define('IMPORT_NOW', 'Importer nu!');
@define('IMPORT_STARTING', 'Starter import procedure...');
@define('IMPORT_FAILED', 'Importeringen fejlede');
@define('IMPORT_DONE', 'Importering gennemført');
@define('IMPORT_WEBLOG_APP', 'Weblog applikation');
@define('EXPORT_FEED', 'Eksporter fuldt RSS feed');
@define('STATUS', 'Status efter import');
@define('IMPORT_GENERIC_RSS', 'Almindelig RSS import');
@define('ACTIVATE_AUTODISCOVERY', 'Send Trackbacks til links fundet i artikler');
@define('WELCOME_TO_ADMIN', 'Velkommen til Serendipity Administrations suiten.');
@define('PLEASE_ENTER_CREDENTIALS', 'Indtast venligst dine adgangsoplysninger herunder.');
@define('ADMIN_FOOTER_POWERED_BY', 'Drives af Serendipity %s og PHP %s');
@define('INSTALL_USEGZIP', 'Benyt gzip komprimerede sider');
@define('INSTALL_USEGZIP_DESC', 'For at fremskynde levering af sider, kan vi komprimere siderne vi sender til den besøgende, givet at hans browser understøtter dette. Dette er anbefalet');
@define('INSTALL_SHOWFUTURE', 'Vis fremtidige artikler');
@define('INSTALL_SHOWFUTURE_DESC', 'Hvis aktiveret, dette vil vise alle fremtidige artikler på din blog. Som standard skjules disse artikler og vises først når udgivelsesdatoen er nået.');
@define('INSTALL_DBPERSISTENT', 'Brug vedvarende forbindelser');
@define('INSTALL_DBPERSISTENT_DESC', 'Aktiver brug af vedvarende database forbindelser, læs mere <a href="http://php.net/manual/features.persistent-connections.php" target="_blank">her</a>. Dette anbefales normalt ikke');
@define('NO_IMAGES_FOUND', 'Ingen billeder fundet');
@define('PERSONAL_SETTINGS', 'Personlige indstillinger');
@define('REFERER', 'Henvisende side');
@define('NOT_FOUND', 'Ikke fundet');
@define('NOT_WRITABLE', 'Ikke skrivbar');
@define('WRITABLE', 'Skrivbar');
@define('PROBLEM_DIAGNOSTIC', 'Grundet en problematisk diagnose, kan du ikke fortsætte med installationen førend ovenstående fejl er rettet');
@define('SELECT_INSTALLATION_TYPE', 'Vælg hvilken installationstype du vil benytte');
@define('WELCOME_TO_INSTALLATION', 'Velkommen til Serendipity Installationen');
@define('FIRST_WE_TAKE_A_LOOK', 'Først kigger vi på dit nuværende setup og vil forsøge at diagnosere eventuelle kompatibilitetsproblemer');
@define('ERRORS_ARE_DISPLAYED_IN', 'Fejl er vist som %s, anbefalinger som %s og succes som %s');
@define('RED', 'rød');
@define('YELLOW', 'gul');
@define('GREEN', 'grøn');
@define('PRE_INSTALLATION_REPORT', 'Serendipity v%s før-installations report');
@define('RECOMMENDED', 'Anbefalet');
@define('ACTUAL', 'Faktisk');
@define('PHPINI_CONFIGURATION', 'php.ini konfiguration');
@define('PHP_INSTALLATION', 'PHP installation');
@define('THEY_DO', 'det gør de');
@define('THEY_DONT', 'det før de ikke');
@define('SIMPLE_INSTALLATION', 'Simpel installation');
@define('EXPERT_INSTALLATION', 'Expert installation');
@define('COMPLETE_INSTALLATION', 'Fuldfør installation');
@define('WONT_INSTALL_DB_AGAIN', 'Installerer ikke database igen');
@define('CHECK_DATABASE_EXISTS', 'Undersøger om databasen og tabllerne allerede findes');
@define('CREATING_PRIMARY_AUTHOR', 'Opretter primær forfatter \'%s\'');
@define('SETTING_DEFAULT_TEMPLATE', 'Sætter standard skabelon');
@define('INSTALLING_DEFAULT_PLUGINS', 'Installerer standard plugins');
@define('SERENDIPITY_INSTALLED', 'Serendipity er nu installeret');
@define('VISIT_BLOG_HERE', 'Besøg din nye blog her');
@define('THANK_YOU_FOR_CHOOSING', 'Tak fordi du valgte Serendipity');
@define('ERROR_DETECTED_IN_INSTALL', 'En fejl blev fundet under installationen');
@define('OPERATING_SYSTEM', 'Operativsystem');
@define('WEBSERVER_SAPI', 'Webserver SAPI');
@define('IMAGE_ROTATE_LEFT', 'Roter billede 90 grader imod uret');
@define('IMAGE_ROTATE_RIGHT', 'Roter billede 90 grader med uret');
@define('TEMPLATE_SET', '\'%s\' er blevet sat som din aktive skabelon');
@define('SEARCH_ERROR', 'Søgefunktionen fungere ikke som forventet. Besked til administratoren: Dette sker muligvis pga. en manglende index key i databasen. På MySQL systemer skal din bruger have rettigheder til at udføre denne query: <pre>CREATE FULLTEXT INDEX entry_idx on %sentries (title,body,extended)</pre> Den specifikke fejl returneret af databasen, var: <pre>%s</pre>');
@define('EDIT_THIS_CAT', ' Redigerer "%s"');
@define('CATEGORY_REMAINING', 'Slet denne kategori og flyt dens artikler ind i denne kategori');
@define('CATEGORY_INDEX', 'Nedenunder er en liste over kategorier der er tilgængelige for dine artikler');
@define('NO_CATEGORIES', 'Ingen kategorier');
@define('RESET_DATE', 'Reset dato');
@define('RESET_DATE_DESC', 'Klik her for at resette datoen til den nuværende tid');
@define('PROBLEM_PERMISSIONS_HOWTO', 'Rettigheder kan gives ved at kører følgende shell kommando: `<em>%s</em>` på det fejlede bibliotek, eller ved at sætte det vha. et FTP program');
@define('WARNING_TEMPLATE_DEPRECATED', 'Advarsel: Din nuværende skabelon bruger en forældet skabelon metode, vi anbefaler du opgraderer, hvis muligt');
@define('ENTRY_PUBLISHED_FUTURE', 'Denne artikel er endnu ikke udgivet.');
@define('ENTRIES_BY', 'Artikler skrevet af %s');
@define('PREVIOUS', 'Forrige');
@define('NEXT', 'Næste');
@define('APPROVE', 'Godkend');
@define('DO_MARKUP_DESCRIPTION', 'Tilføj markup-transformationer på teksten (smilies, shortcut markups via *, /, _, ...). Hvis du slår dette fra vil al HTML-kode i teksten blive bibeholdt.');
@define('CATEGORY_ALREADY_EXIST', 'En kategori med navnet "%s" findes allerede');
@define('IMPORT_NOTES', 'Note:');
@define('ERROR_FILE_FORBIDDEN', 'Det er ikke tilladt at uploade filer med aktivt indhold');
@define('ADMIN', 'Administration'); // Re-Translate
@define('ADMIN_FRONTPAGE', 'Forside');
@define('QUOTE', 'Citer');
@define('IFRAME_SAVE', 'Serendipity gemmer nu din artikel, sender trackbacks og udfører mulige XML-RPC calls. Dette kan tage noget tid..');
@define('IFRAME_SAVE_DRAFT', 'Et udkast af denne artikel er blevet gemt');
@define('IFRAME_PREVIEW', 'Serendipity opretter nu et preview af din artikel...');
@define('IFRAME_WARNING', 'Din browser understøtter ikke iframes. Åbn serendipity_config.inc.php og sæt $serendipity[\'use_iframe\'] til FALSE.');
@define('NONE', 'ingen');
@define('USERCONF_CAT_DEFAULT_NEW_ENTRY', 'Standard indstillinger for nye artikler');
@define('UPGRADE', 'Opgrader');
@define('UPGRADE_TO_VERSION', 'Opgrader til v%s');
@define('DELETE_DIRECTORY', 'Slet mappe');
@define('DELETE_DIRECTORY_DESC', 'Du er ved at slette indholdet af en mappe der indeholder multimedia filer, muligvis filer brugt i dine artikler.');
@define('FORCE_DELETE', 'Slet ALLE filer i denne mappe, inklusiv dem ikke kendt af Serendipity');
@define('CREATE_DIRECTORY', 'Opret mappe');
@define('CREATE_NEW_DIRECTORY', 'Opret ny mappe');
@define('CREATE_DIRECTORY_DESC', 'Her kan du oprette en ny mappe til at placere dine multimedia filer i. Vælg navnet på din nye mappe, og vælg en passende mappe at oprette den i.');
@define('BASE_DIRECTORY', 'Rodmappe');
@define('USERLEVEL_EDITOR_DESC', 'Standard editor');
@define('USERLEVEL_CHIEF_DESC', 'Chefeditor');
@define('USERLEVEL_ADMIN_DESC', 'Administrator');
@define('USERCONF_USERLEVEL', 'Adgangsniveau');
@define('USERCONF_USERLEVEL_DESC', 'Dette niveau er brugt til at bestemme hvilken type adgang brugeren har til bloggen');
@define('USER_SELF_INFO', 'Logget ind som %s (%s)');
@define('ADMIN_ENTRIES', 'Artikler');
@define('RECHECK_INSTALLATION', 'Check installation igen');
@define('IMAGICK_EXEC_ERROR', 'Kunne ikke eksekvere: "%s", fejl: %s, return var: %d');
@define('INSTALL_OFFSET_DESC', 'Indtast antallet af timer mellem tiden på din webserver (%clock%) og din fortrukne tidszone');
@define('UNMET_REQUIREMENTS', 'Uopfyldt krav: %s');
@define('CHARSET', 'Karaktersæt');
@define('AUTOLANG', 'Brug som standard, brugerens browser sprog');
@define('AUTOLANG_DESC', 'Hvis aktiveret, vil brugerens browsersprog benyttes til at finde det viste sprog i dine artikler og interface.');
@define('INSTALL_AUTODETECT_URL', 'Autoudregn anvendt HTTP-Host');
@define('INSTALL_AUTODETECT_URL_DESC', 'Hvis denne er sat til "ja", vil Serendipity sikre at den HTTP Host der anvendes af dine besøgende, anvendes som din BaseURL indstilling. Aktiverer du dette, kan du bruge flere domænenavne på samme Serendipity Blog.');
@define('CONVERT_HTMLENTITIES', 'Prøv at konvertere HTML entities automatisk?');
@define('EMPTY_SETTING', 'Du angav ikke en gyldig værdi for "%s"!');
@define('USERCONF_REALNAME', 'Rigtigt navn');
@define('USERCONF_REALNAME_DESC', 'Det fulde navn på forfatteren. Dette er navnet set af læserne');
@define('HOTLINK_DONE', 'Fil blev hotlinked.<br />Færdig.');
@define('ENTER_MEDIA_URL_METHOD', 'Afhentningsmetode:');
@define('ADD_MEDIA_BLAHBLAH_NOTE', 'Bemærk: Hvis du vælger at hotlinke til en server, bør du sikre dig tilladelse til at gøre dette, eller være ejeren af serveren. Hotlink gør det muligt at bruge eksterne billeder, uden at gemme dem lokalt.');
@define('MEDIA_HOTLINKED', 'hotlinked');
@define('FETCH_METHOD_IMAGE', 'Hent billede til din server');
@define('FETCH_METHOD_HOTLINK', 'Hotlink til server');
@define('DELETE_HOTLINK_FILE', 'Slet den hotlinkede fil ved navn <b>%s</b>');
@define('SYNDICATION_PLUGIN_SHOW_MAIL', 'Vis E-Mail adresser?');
@define('IMAGE_MORE_INPUT', 'Tilføj flere billeder');
@define('BACKEND_TITLE', 'Yderligere information på plugin konfigurations siden');
@define('BACKEND_TITLE_FOR_NUGGET', 'Her kan du indtaste en tekst som vises på plugin konfigurations siden, sammen med beskrivelsen af din HTML Nugget. Har du flere HTML Nuggets med tom titel kan dette hjælpe med at genkende dem fra hinanden.');
@define('CATEGORIES_ALLOW_SELECT', 'Tillad brugere at vise flere kategorier samtidig?');
@define('CATEGORIES_ALLOW_SELECT_DESC', 'Hvis denne mulighed aktiveres vises en checkboks ud for hver kategori i denne sidebar. Brugere kan afkrydse disse bokse og derefter se indlæg afhængig af deres valg.');
@define('PAGE_BROWSE_PLUGINS', 'Side %s af %s, i alt %s plugins.');
@define('INSTALL_CAT_PERMALINKS', 'Permalinks');
@define('INSTALL_CAT_PERMALINKS_DESC', 'Angiver forskellige URL mønstre som definerer permanente links i din blog. Det anbefales at bruge standardværdierne; hvis ikke, bør du bruge %id% værdien hvor muligt for at forhindre at Serendipity skal slå URL\'en op i databasen.');
@define('INSTALL_PERMALINK', 'Permalink URL struktur');
@define('INSTALL_PERMALINK_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artiklerne bliver tilgængelige. Du kan bruge variablene %id%, %title%, %day%, %month%, %year% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_AUTHOR', 'Permalink forfatter URL struktur');
@define('INSTALL_PERMALINK_AUTHOR_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artikler fra bestemte forfattere bliver tilgængelige. Du kan bruge variablene %id%, %realname%, %username%, %email% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_CATEGORY', 'Permalink kategori URL struktur');
@define('INSTALL_PERMALINK_CATEGORY_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor artikler fra bestemte kategorier bliver tilgængelige. Du kan anvende de variable %id%, %name%, %description% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_FEEDCATEGORY', 'Permalink RSS-Feed kategori URL struktur');
@define('INSTALL_PERMALINK_FEEDCATEGORY_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor RSS-feeds fra bestemte kategorier bliver tilgængelige. Du kan anvende de variable %id%, %name%, %description% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_ARCHIVESPATH', 'Sti til arkiver');
@define('INSTALL_PERMALINK_ARCHIVEPATH', 'Sti til arkiv');
@define('INSTALL_PERMALINK_CATEGORIESPATH', 'Sti til kategorier');
@define('INSTALL_PERMALINK_UNSUBSCRIBEPATH', 'Sti til  afmeldings kommentarer');
@define('INSTALL_PERMALINK_DELETEPATH', 'Sti til sletning af kommentarer');
@define('INSTALL_PERMALINK_APPROVEPATH', 'Sti til godkendelse af kommentarer');
@define('INSTALL_PERMALINK_FEEDSPATH', 'Sti til RSS feeds');
@define('INSTALL_PERMALINK_PLUGINPATH', 'Sti til et plugin');
@define('INSTALL_PERMALINK_ADMINPATH', 'Sti til admin');
@define('INSTALL_PERMALINK_SEARCHPATH', 'Sti til søgning');
@define('INSTALL_CAL', 'Kalendar type');
@define('INSTALL_CAL_DESC', 'Vælg dit kalenderformat');
@define('REPLY', 'Svar');
@define('USERCONF_GROUPS', 'Gruppe medlemsskab');
@define('USERCONF_GROUPS_DESC', 'Brugeren er medlem af følgende grupper. Det er muligt at være medlem af flere grupper.');
@define('MANAGE_GROUPS', 'Håndter grupper');
@define('DELETED_GROUP', 'Gruppe #%d %s slettet.');
@define('CREATED_GROUP', 'En nye gruppe %s er blevet oprettet');
@define('MODIFIED_GROUP', 'Egenskaberne for gruppen %s er blevet ændret');
@define('GROUP', 'Group');
@define('CREATE_NEW_GROUP', 'Opret ny gruppe');
@define('DELETE_GROUP', 'Slet gruppe  #%d %s. Er du sikker?');
@define('USERLEVEL_OBSOLETE', 'BEMÆRK: Brugerniveau indstillingen anvendes nu kun til bagud kompatibilitet. Bruger privilegier angives nu ved hjælp af gruppe medlemskaber!');
@define('SYNDICATION_PLUGIN_FEEDBURNERID', 'FeedBurner ID');
@define('SYNDICATION_PLUGIN_FEEDBURNERID_DESC', 'ID på det feed du ønsker at offentliggøre');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG', 'FeedBurner billede');
@define('SYNDICATION_PLUGIN_FEEDBURNERIMG_DESC', 'Navn på billede der skal vises (ingenting giver en tæller), billedet skal eksistere hos  feedburner.com, f.eks.: fbapix.gif');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE', 'FeedBurner titel');
@define('SYNDICATION_PLUGIN_FEEDBURNERTITLE_DESC', 'Eventuel titel der skal vises ved billedet');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT', 'FeedBurner billedtekst');
@define('SYNDICATION_PLUGIN_FEEDBURNERALT_DESC', 'Eventuel \'hover\' tekst til billedet');
@define('SEARCH_TOO_SHORT', 'Din søgestreng skal være længere end 3 tegn. Du kan sætte * efter dit søgeord for at søge på kortere dele af ord (f.eks. s9y*)');
@define('INSTALL_DBPORT', 'Database port');
@define('INSTALL_DBPORT_DESC', 'Denne port anvendes til at forbinde til din databaseserver');
@define('PLUGIN_GROUP_FRONTEND_EXTERNAL_SERVICES', 'Frontend: Eksterne tjenester');
@define('PLUGIN_GROUP_FRONTEND_FEATURES', 'Frontend: Features');
@define('PLUGIN_GROUP_FRONTEND_FULL_MODS', 'Frontend: Fulde moduler');
@define('PLUGIN_GROUP_FRONTEND_VIEWS', 'Frontend: Views');
@define('PLUGIN_GROUP_FRONTEND_ENTRY_RELATED', 'Frontend: Artikel relateret');
@define('PLUGIN_GROUP_BACKEND_EDITOR', 'Backend: Editor');
@define('PLUGIN_GROUP_BACKEND_USERMANAGEMENT', 'Backend: Brugerhåndtering');
@define('PLUGIN_GROUP_BACKEND_METAINFORMATION', 'Backend: Meta information');
@define('PLUGIN_GROUP_BACKEND_TEMPLATES', 'Backend: Skabeloner');
@define('PLUGIN_GROUP_BACKEND_FEATURES', 'Backend: Features');
@define('PLUGIN_GROUP_IMAGES', 'Billeder');
@define('PLUGIN_GROUP_ANTISPAM', 'Antispam');
@define('PLUGIN_GROUP_MARKUP', 'Markup');
@define('PLUGIN_GROUP_STATISTICS', 'Statistik');
@define('PERMISSION_PERSONALCONFIGURATION', 'personalConfiguration: Adgang til personlig konfiguration');
@define('PERMISSION_PERSONALCONFIGURATIONUSERLEVEL', 'personalConfigurationUserlevel: Ændre brugerniveauer');
@define('PERMISSION_PERSONALCONFIGURATIONNOCREATE', 'personalConfigurationNoCreate: Ændre "forbyd oprettelse af artikler"');
@define('PERMISSION_PERSONALCONFIGURATIONRIGHTPUBLISH', 'personalConfigurationRightPublish: Ændre rettighed til at offentliggøre artikler');
@define('PERMISSION_SITECONFIGURATION', 'siteConfiguration: Adgang til system konfiguration');
@define('PERMISSION_BLOGCONFIGURATION', 'blogConfiguration: Adgang til blog-specifik konfiguration');
@define('PERMISSION_ADMINENTRIES', 'adminEntries: Administrer artikler');
@define('PERMISSION_ADMINENTRIESMAINTAINOTHERS', 'adminEntriesMaintainOthers: Administrer andres artikler');
@define('PERMISSION_ADMINIMPORT', 'adminImport: Importer artikler');
@define('PERMISSION_ADMINCATEGORIES', 'adminCategories: Administrer kategorier');
@define('PERMISSION_ADMINCATEGORIESMAINTAINOTHERS', 'adminCategoriesMaintainOthers: Administrer andre brugeres kategorier');
@define('PERMISSION_ADMINCATEGORIESDELETE', 'adminCategoriesDelete: Slet kategorier');
@define('PERMISSION_ADMINUSERS', 'adminUsers: Administrer brugere');
@define('PERMISSION_ADMINUSERSDELETE', 'adminUsersDelete: Slet brugere');
@define('PERMISSION_ADMINUSERSEDITUSERLEVEL', 'adminUsersEditUserlevel: Ændre brugerniveau');
@define('PERMISSION_ADMINUSERSMAINTAINSAME', 'adminUsersMaintainSame: Administrer brugere i din(e) gruppe(r)');
@define('PERMISSION_ADMINUSERSMAINTAINOTHERS', 'adminUsersMaintainOthers: Administrer bruger der ikke er i din(e) gruppe(r)');
@define('PERMISSION_ADMINUSERSCREATENEW', 'adminUsersCreateNew: Opret nye brugere');
@define('PERMISSION_ADMINUSERSGROUPS', 'adminUsersGroups: Administrer grupper');
@define('PERMISSION_ADMINPLUGINS', 'adminPlugins: Administrer plugins');
@define('PERMISSION_ADMINPLUGINSMAINTAINOTHERS', 'adminPluginsMaintainOthers: Administrer andre brugeres plugins');
@define('PERMISSION_ADMINIMAGES', 'adminImages: Administrer media filer');
@define('PERMISSION_ADMINIMAGESDIRECTORIES', 'adminImagesDirectories: Administrer media biblioteker');
@define('PERMISSION_ADMINIMAGESADD', 'adminImagesAdd: Tilføj nye media filer');
@define('PERMISSION_ADMINIMAGESDELETE', 'adminImagesDelete: Slet media filer');
@define('PERMISSION_ADMINIMAGESMAINTAINOTHERS', 'adminImagesMaintainOthers: Administrer andres media filer');
@define('PERMISSION_ADMINIMAGESVIEW', 'adminImagesView: Vis media filer');
@define('PERMISSION_ADMINIMAGESSYNC', 'adminImagesSync: Opdater minibilleder');
@define('PERMISSION_ADMINCOMMENTS', 'adminComments: Administrer kommentarer');
@define('PERMISSION_ADMINTEMPLATES', 'adminTemplates: Administrer skabeloner');
@define('INSTALL_BLOG_EMAIL', 'Bloggens emailadresse');
@define('INSTALL_BLOG_EMAIL_DESC', 'Her angives emailadressen som anvendes i \'fra\' feltet på udgående email fra bloggen. Vær opmærksom på at mange mailservere afviser email med ukendt eller ikke eksisterende emailadresse i \'fra\' feltet.');
@define('CATEGORIES_PARENT_BASE', 'Vis kun kategorier herunder...');
@define('CATEGORIES_PARENT_BASE_DESC', 'Du kan vælge en forælder kategori, så kun kategorierne herunder vises.');
@define('CATEGORIES_HIDE_PARALLEL', 'Skjul kategorier som ikke er en del af kategoritræet');
@define('CATEGORIES_HIDE_PARALLEL_DESC', 'Hvis du ønsker at skjule kategorier som er del af et andet kategoritræ skal du vælge \'Ja\' her. Denne feature giver mest mening i en flerbruger blog installation, som anvender "Properties/Tempaltes of categories" pluginet.');
@define('PERMISSION_ADMINIMAGESVIEWOTHERS', 'adminImagesViewOthers: Vis andre brugeres media filer');
@define('CHARSET_NATIVE', 'Native');
@define('INSTALL_CHARSET', 'Karaktersæt valg');
@define('INSTALL_CHARSET_DESC', 'Her kan du vælge mellem UTF-8 eller \'native\' (lokalt,  f.eks. UTF-8) karaktersæt. Nogle sprog har kun UTF-8 oversættelsen, så at sætte valget til \'native\' vil ikke have nogen effekt. UTF-8 anbefales til nyinstallationer. Lad være med at ændre denne indstilling hvis du allerede har lavet artikler med special karakterer - det kan medføre dine artikler vises forkert. Læs mere om alt dette på <a href="http://www.s9y.org/index.php?node=46">http://www.s9y.org/index.php?node=46</a>');
@define('CALENDAR_ENABLE_EXTERNAL_EVENTS', 'Aktiver Plugin API hook');
@define('CALENDAR_EXTEVENT_DESC', 'Hvis aktiveret kan plugins "hægte" sig på kalenderen og fremhæve deres egne events. Aktiver kun hvis du har installeret plugins der kræver dette, da det forringer performance.');
@define('XMLRPC_NO_LONGER_BUNDLED', 'Serendipity\'s XML-RPC API interface leveres ikke længere sammen med Serendipity på grund af gentagne sikkerhedsproblemer med dette API. Du er derfor nødt til at installere XML-RPC pluginet for at kunne bruge XML-RPC API. URL\'en i dine programmer ændres IKKE - så snart pluginet er installeret vil du igen være istand til at bruge dette API.');
@define('PERM_READ', 'Læse rettighed');
@define('PERM_WRITE', 'Skrive rettighed');

@define('PERM_DENIED', 'Permission denied.');
@define('INSTALL_ACL', 'Anvend læserettigheder for kategorier');
@define('INSTALL_ACL_DESC', 'Hvis aktiveret anvendes grupperettigheder for brugere der er logget ind. I modsat fald anvendes læserettigheder for kategorier ikke, men din blog bliver til gengæld lidt hurtigere. Så har du ikke brug for multibruger læserettigheder  i din blog bør du vælge \'nej\' her.');
@define('PLUGIN_API_VALIDATE_ERROR', 'Konfigurations syntax forkert for indstilling "%s". Skal bruge indhold af typen "%s".');
@define('USERCONF_CHECK_PASSWORD', 'Nuværende kodeord');
@define('USERCONF_CHECK_PASSWORD_DESC', 'Hvis du ændrer kodeord i feltet herover skal du indtaste dit nuværende kodeord her.');
@define('USERCONF_CHECK_PASSWORD_ERROR', 'Du indtastede ikke det rigtige nuværende kodeord, og kan derfor ikke ændre kodeord, din ændring blev ikke gemt.');
@define('ERROR_XSRF', 'Your browser did not sent a valid HTTP-Referrer string. This may have either been caused by a misconfigured browser/proxy or by a Cross Site Request Forgery (XSRF) aimed at you. The action you requested could not be completed.');
@define('INSTALL_PERMALINK_FEEDAUTHOR_DESC', 'Her kan du angive den relative URL struktur fra din grund URL til hvor RSS-feeds fra bestemte forfattere bliver tilgængelige. Du kan anvende de variable værdier %id%, %realname%, %username%, %email% samt alle andre karakterer.');
@define('INSTALL_PERMALINK_FEEDAUTHOR', 'Permalink RSS-Feed forfatter URL struktur');
@define('INSTALL_PERMALINK_AUTHORSPATH', 'Sti til forfattere');
@define('AUTHORS', 'Forfattere');
@define('AUTHORS_ALLOW_SELECT', 'Tillad besøgende at vise flere forfattere samtidig?');
@define('AUTHORS_ALLOW_SELECT_DESC', 'Hvis aktiveret vil der vises en checkboks ud for hver forfatter i sidebaren. Brugere kan så afkrydse hvilke forfatteres artikler der skal vises.');
@define('AUTHOR_PLUGIN_DESC', 'Vis en liste over forfattere');
@define('CATEGORY_PLUGIN_TEMPLATE', 'Aktiver Smarty-skabeloner?');
@define('CATEGORY_PLUGIN_TEMPLATE_DESC', 'Aktiveres denne indstilling, vil der anvendes Smarty skabelon features i opbygningen af kategorilisten, du har mulighed for at ændre layout for listen i "plugin_categories.tpl" skabelon filen. Bemærk, denne indstilling koster performance, så har du ikke behov for den, så lad være med at aktivere den.');
@define('CATEGORY_PLUGIN_SHOWCOUNT', 'Vis antal artikler pr. kategori?');
@define('AUTHORS_SHOW_ARTICLE_COUNT', 'Vis antal artikler ved siden af forfatternavn?');
@define('AUTHORS_SHOW_ARTICLE_COUNT_DESC', 'Hvis aktiv, vises antallet af artikler forfatteren har skrevet i paranteser ved siden af forfatternavnet.');
@define('CUSTOM_ADMIN_INTERFACE', 'Tilpasset administrator interface');
 
@define('COMMENT_NOT_ADDED', 'Din kommentar kunne ikke tilføjes af en af følgende grunde: kommentarer til denne artikel er blevet deaktiveret, du indtastede forkerte data, eller din kommentar blev fanget af antispam beskyttelsen');
@define('INSTALL_TRACKREF', 'Visning af referencer?');
@define('INSTALL_TRACKREF_DESC', 'Aktiverer du reference visning, vil du kunne se hvilke sites der henviser til dine artikler. Dette bliver tit misbrugt til spam.');
@define('CATEGORIES_HIDE_PARENT', 'Skjul den valgte overkategori?');
@define('CATEGORIES_HIDE_PARENT_DESC', 'Hvis du begrænser visningen af kategorier til en specifik kategori, vil du som standard se overkategorien i listen. Deaktiveres denne indstilling vises overkategorien ikke.');
@define('WARNING_NO_GROUPS_SELECTED', 'Advarsel: Du har ikke valgt noget gruppemedlemskab. Da dette ville logge dig ud af brugergruppeadministrationen, er dine ændringer derfor ikke gemt.');
@define('INSTALL_RSSFETCHLIMIT', 'Artikler i feeds');
@define('INSTALL_RSSFETCHLIMIT_DESC', 'Antallet af artikler der skal vises på hver side i RSS feeds.');
@define('INSTAL_DB_UTF8', 'Brug database karaktersæt-oversættelse');
@define('INSTAL_DB_UTF8_DESC', 'Udfører MySQL kommandoen "SET NAMES .." for at angive det krævede karaktersæt. Deaktiver hvis du ser underlige karakterer i din blog.');
@define('ONTHEFLYSYNCH', 'Automatisk medie synkronisering');
@define('ONTHEFLYSYNCH_DESC', 'Hvis aktiv, vil  Serendipity sammenligne medie databasen med filerne der er gemt på serveren og synkronisere disse.');
@define('USERCONF_CHECK_USERNAME_ERROR', 'Brugernavn skal indtastes.');
@define('FURTHER_LINKS', 'Further Links');
@define('FURTHER_LINKS_S9Y', 'Serendipity hjemmeside');
@define('FURTHER_LINKS_S9Y_DOCS', 'Serendipity dokumentation');
@define('FURTHER_LINKS_S9Y_BLOG', 'Officiel blog');
@define('FURTHER_LINKS_S9Y_FORUMS', 'Fora');
@define('FURTHER_LINKS_S9Y_SPARTACUS', 'Spartacus');
@define('COMMENT_IS_DELETED', '(Kommentar slettet)');

@define('CURRENT_AUTHOR', 'Aktuel forfatter');

@define('WORD_NEW', 'Ny');
@define('SHOW_MEDIA_TOOLBAR', 'Vis værktøjslinie i medievælger popup?');
@define('MEDIA_KEYWORDS', 'Medie nøgleord');
@define('MEDIA_KEYWORDS_DESC', 'Indtast en ";" adskilt liste af ord du vil prædefinere som nøgleord for medie filer.');
@define('MEDIA_EXIF', 'Importer EXIF/JPEG billeddata');
@define('MEDIA_EXIF_DESC', 'Hvis aktiv, vil EXIF/JPEG metadata blive indlæst og gemt i databasen for senere at kunne vises i medie galleriet.');
@define('MEDIA_PROP', 'Medie egenskaber');


@define('GO_ADD_PROPERTIES', 'Go & enter properties');
@define('MEDIA_PROPERTY_DPI', 'DPI');
@define('MEDIA_PROPERTY_COPYRIGHT', 'Copyright');
@define('MEDIA_PROPERTY_COMMENT1', 'Kort kommentar');
@define('MEDIA_PROPERTY_COMMENT2', 'Lang kommentar');
@define('MEDIA_PROPERTY_TITLE', 'Titel');
@define('MEDIA_PROP_DESC', 'Indtast ";" adskilt liste af felter/egenskaber du vil definere for hver mediefil. ');
@define('MEDIA_PROP_MULTIDESC', '(Du kan tilføje ":MULTI" efter ethvert felt for at angive dette felt indeholder en lang tekst i stedet for blot nogle karakterer)');

@define('STYLE_OPTIONS_NONE', 'Denne skabelon/stil har ikke nogen specifikke indstillinger. Læs den tekniske dokumentation på www.s9y.org, punktet "Configuration of Theme options", for at se hvordan din skabelon kan anvende indstillinger.');
@define('STYLE_OPTIONS', 'Tema/stil indstillinger');

@define('PLUGIN_AVAILABLE_COUNT', 'Total: %d plugins.');

@define('SYNDICATION_RFC2616', 'Aktiver RSS-feeds der overholder RFC2616');
@define('SYNDICATION_RFC2616_DESC', 'Hvis IKKE RFC2616 overholdes vil alle forespørgsler til Serendipity returnere artikler ændret siden  tidspunktet for sidste forespørgsel. Dvs \'nej\' medfører at dine besøgende får alle artikler siden sidst. På den anden side, nogle RSS aggregatorer som f.eks. \'Planet\' opfører sig underligt med denne indstilling da den jo ikke overholder RFC2616. Læs eventuelt mere om problemet her <a href="<a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a>"><a href="https://sourceforge.net/tracker/index.php?func=detail&amp;aid=1461728&amp;group_id=75065&amp;atid=542822" target="_blank" rel="nofollow">SourceForge</a></a>');
@define('MEDIA_PROPERTY_DATE', 'Tilhørende dato');
@define('MEDIA_PROPERTY_RUN_LENGTH', 'Spilletid');
@define('FILENAME_REASSIGNED', 'Nyt filnavn automagisk tildelt: %s');
@define('MEDIA_UPLOAD_SIZE', 'Max. fil upload størrelse');
@define('MEDIA_UPLOAD_SIZE_DESC', 'Angiv maximal filstørrelse for uploadede filer. Denne indstilling kan overskrives af en server indstilling i PHP.ini: upload_max_filesize, post_max_size, max_input_time har alle højere prioritet end denne indstilling. Indtaster du ikke noget, anvendes server indstillingerne.');
@define('MEDIA_UPLOAD_SIZEERROR', 'Fejl: Du kan ikke uploade filer større end %s bytes!');
@define('MEDIA_UPLOAD_MAXWIDTH', 'Max. bredde for uploadede billeder');
@define('MEDIA_UPLOAD_MAXWIDTH_DESC', 'Indtast den maximale bredde i pixels, for uploadede billeder.');
@define('MEDIA_UPLOAD_MAXHEIGHT', 'Max. højde for uploadede billeder');
@define('MEDIA_UPLOAD_MAXHEIGHT_DESC', 'Indtast den maximale højde i pixels, for uploadede billeder.');
@define('MEDIA_UPLOAD_DIMERROR', 'Fejl: Du kan ikke uploade billeder der er større end %s x %s pixels!');

@define('MEDIA_TARGET', 'Target for this link');
@define('MEDIA_TARGET_JS', 'Popup window (via JavaScript, tilpasset størrelse)');
@define('MEDIA_ENTRY', 'Selvstændig artikel');
@define('MEDIA_TARGET_BLANK', 'Popup window (via target=_blank)');

@define('MEDIA_DYN_RESIZE', 'Tillad dynamiske billedstørrelser?');
@define('MEDIA_DYN_RESIZE_DESC', 'Hvis aktiveret, kan medievælgeren returnere billeder i vilkårlige størrelser, styret af en GET variabel, billederne caches og kan derfor generere mange filer.');

@define('MEDIA_DIRECTORY_MOVED', 'Bibliotek og filer blev flyttet til %s');
@define('MEDIA_DIRECTORY_MOVE_ERROR', 'Bibliotek og filer kunne ikke flyttes til %s!');
@define('MEDIA_DIRECTORY_MOVE_ENTRY', 'På IKKE-MySQL databaser, understøttes iteration gennem artikler for at opdatere stier til biblioteker ikke. Du bliver nødt til manuelt at redigere dine artikler og rette stierne, er dette for besværligt kan du flytte dit bibliotek tilbage til den gamle placering.');
@define('MEDIA_DIRECTORY_MOVE_ENTRIES', 'Stien til det flyttede bibliotek er opdateret i %s artikler.');
@define('PLUGIN_ACTIVE', 'Aktiv');
@define('PLUGIN_INACTIVE', 'Inaktiv');
@define('PREFERENCE_USE_JS', 'Aktiver advanceret JS brug?');
@define('PREFERENCE_USE_JS_DESC', 'Hvis aktiveret, vil der blive anvendt advancerede Javascript funktioner for at give en forbedret brugeroplevelse, f.eks. i plugin konfigurationen, hvor drag & drop omrokering af plugins bliver mulig.');

@define('PREFERENCE_USE_JS_WARNING', '(Denne side anvender advanceret JavaScript. Får du funktionalitetsproblemer, så slå advanceret JS brug fra i dine personlige indstillinger, eller deaktiver Javascript i din browser)');

@define('INSTALL_PERMALINK_COMMENTSPATH', 'Sti til kommentarer');
@define('PERM_SET_CHILD', 'Sæt de samme rettigheder på alle underliggende biblioteker');
@define('PERMISSION_FORBIDDEN_PLUGINS', 'Forbidden plugins');
@define('PERMISSION_FORBIDDEN_HOOKS', 'Forbidden events');
@define('PERMISSION_FORBIDDEN_ENABLE', 'Aktiver plugin adgangskontrol for grupper?');
@define('PERMISSION_FORBIDDEN_ENABLE_DESC', 'Mulighed for at bestemme hvilke grupper der må anvende hvilke plugins.');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET', 'Bookmarklet');
@define('FURTHER_LINKS_S9Y_BOOKMARKLET_DESC', 'Bookmark this link and then use it on any page you want to blog about to quickly access your Serendipity Blog.');
@define('IMPORT_WP_PAGES', 'Also fetch attachments and staticpages as normal blog entries?');
@define('USERCONF_CREATE', 'Disable user / forbid activity?');
@define('USERCONF_CREATE_DESC', 'If selected, the user will not have any editing or creation possibilities on the blog anymore. When logging in to the backend, he cannot do anything else apart from logging out and viewing his personal configuration.');
@define('CATEGORY_HIDE_SUB', 'Hide postings made to sub-categories?');
@define('CATEGORY_HIDE_SUB_DESC', 'By default, when you browse a category also entries of any subcategory are displayed. If this option is turned on, only postings of the currently selected category are displayed.');
@define('PINGBACK_SENDING', 'Sending pingback to URI %s...');
@define('PINGBACK_SENT', 'Pingback successful');
@define('PINGBACK_FAILED', 'Pingback failed: %s');
@define('PINGBACK_NOT_FOUND', 'No pingback-URI found.');
@define('CATEGORY_PLUGIN_HIDEZEROCOUNT', 'Hide archives link when no entries were made in that timespan (requires counting entries)');
@define('RSS_IMPORT_WPXRSS', 'WordPress eXtended RSS import, requires PHP5 and might take up much memory');
